@echo off
@rem ==========================================================================
@rem == Licensed Materials - Property of IBM Corporation
@rem == (C) Copyright IBM Corporation 2017
@rem ==========================================================================
@rem Deploys SPE Java patch resources
@rem Run this from an SPE console window. This is a WINDOWS ONLY script.
@rem ==========================================================================
@rem
if not defined InSPEConsole echo This command must be run in an SPE console session
if not defined InSPEConsole goto :EOF

setlocal EnableDelayedExpansion

rem Generate timestamp for backup dir
for /f "delims=" %%a in ('wmic OS Get localdatetime  ^| find "."') do set dt=%%a
set TIMESTAMP=D%dt:~0,8%.T%dt:~8,6%

set PRODUCT=SPE
set SPE_V_R=2.0
set JRE_32_ZIP=ibm-java-jre-70-win-i386.zip
set JRE_64_ZIP=ibm-java-jre-70-win-x86_64.zip

set PATCH_ZIP=
set MESSAGE=Invalid option %1

:READ_COMMAND_LINE_PARMS
if "%1"=="" goto VALIDATE_PATCH_ZIP

rem read in -j
if /i "%1"=="-j" (
rem read in the -j value: \path\to\patch.zip
    set PATCH_ZIP=%2
    shift
    goto READ_NEXT
)

rem help syntax
if /i "%1"=="/?" goto SYNTAX

echo %MESSAGE%
echo.
goto SYNTAX

:READ_NEXT
shift
goto READ_COMMAND_LINE_PARMS

:VALIDATE_PATCH_ZIP
echo PATCH_ZIP=%PATCH_ZIP%
set MESSAGE=Missing mandatory parameter -j
if not defined PATCH_ZIP goto ERROR
set MESSAGE=Specify the volume name for %PATCH_ZIP%
echo %PATCH_ZIP% | findstr ":" > nul
if ERRORLEVEL 1 goto ERROR 
set MESSAGE=%PRODUCT% Java patch zip file does not exist: %PATCH_ZIP%
if not exist %PATCH_ZIP% goto ERROR
rem extract the last four characters from the zip name
set ZIP_EXT=%PATCH_ZIP:~-4%
rem remove the last character. it might be a double quote
set ZIP_EXT=%ZIP_EXT:~0,-1%
set MESSAGE=Invalid zip file name extension: %ZIP_EXT%
rem if zip path was specified with double quotes
if /i "%ZIP_EXT%"=="zip" goto VALIDATE_OS_BITS
rem if zip path was not specified with double quotes
if /i "%ZIP_EXT%"==".zi" (
    set PATCH_ZIP="%PATCH_ZIP%"
    goto VALIDATE_OS_BITS
)
goto ERROR

:VALIDATE_OS_BITS
for %%j in (%PATCH_ZIP%) do (
    Set ZIP_NAME=%%~nxj
)
echo ZIP_NAME=%ZIP_NAME%
rem use zip filename to check if local OS matches target OS
set MESSAGE=%ZIP_NAME% cannot be applied to a Windows environment
if /i "%ZIP_NAME%"=="%JRE_64_ZIP%" (
    set MESSAGE=%ZIP_NAME% cannot be applied to a Windows 32-bit environment
    wmic OS Get osarchitecture | findstr "64-bit" > nul
    if ERRORLEVEL 1 goto ERROR
    goto VALIDATE_SPE_VERSION
)
if /i "%ZIP_NAME%"=="%JRE_32_ZIP%" goto VALIDATE_SPE_VERSION
rem invalid file for the current platform
goto ERROR

:VALIDATE_SPE_VERSION
set MESSAGE=%ZIP_NAME% cannot be applied to %PRODUCT% %SPE_V_R%
if not exist "%SPE_INSTALL_DIR%\jars\spe-%SPE_V_R%-core.jar" goto ERROR

:EXTRACT_FILES
rem Generate WORK_DIR name and extract zip to it
set NO_ZIP_NAME=%ZIP_NAME:~0,-4%
echo NO_ZIP_NAME=%NO_ZIP_NAME%
set WORK_DIR="%SPE_INSTALL_DIR%\%NO_ZIP_NAME%"
echo WORK_DIR=%WORK_DIR%
set MESSAGE=Failed to remove %WORK_DIR%
if exist %WORK_DIR% rd /s /q %WORK_DIR%
if ERRORLEVEL 1 goto ERROR
echo.
echo Extracting files...
set MESSAGE=Failed to extract %PATCH_ZIP% to %WORK_DIR%
call :UNZIP_FILE %WORK_DIR% %PATCH_ZIP%
if ERRORLEVEL 1 goto ERROR
set MESSAGE=Failed to change directory to %WORK_DIR%
cd %WORK_DIR%
if ERRORLEVEL 1 goto ERROR

:CREATE_BACKUP
cd "%SPE_INSTALL_DIR%"
set BACKUP_DIR=backups\%TIMESTAMP%_PATCH
if not exist %BACKUP_DIR% (
    echo.
    echo Creating %BACKUP_DIR% directory
    set MESSAGE=Failed to create %BACKUP_DIR% directory
    md %BACKUP_DIR%
    if ERRORLEVEL 1 goto ERROR
)
echo.
echo Backing up "%SPE_INSTALL_DIR%\java"...
if exist "%SPE_INSTALL_DIR%\java" (
    set MESSAGE=Failed to move "%SPE_INSTALL_DIR%\java" to %BACKUP_DIR%
    move "%SPE_INSTALL_DIR%\java" %BACKUP_DIR%
    if ERRORLEVEL 1 goto ERROR
)

:DEPLOY_PATCH_FILES
echo.
echo Deploying patch files...
if not exist "%SPE_INSTALL_DIR%\java" (
    set MESSAGE=Failed to create "%SPE_INSTALL_DIR%\java" directory
    md "%SPE_INSTALL_DIR%\java"
    if ERRORLEVEL 1 goto ERROR
)
cd %WORK_DIR%
echo Moving jre\bin to "%SPE_INSTALL_DIR%\java"
set MESSAGE=Failed to move jre\bin to "%SPE_INSTALL_DIR%\java"
move jre\bin "%SPE_INSTALL_DIR%\java\"
if ERRORLEVEL 1 goto ERROR
echo Moving jre\lib to "%SPE_INSTALL_DIR%\java"
set MESSAGE=Failed to move jre\lib to "%SPE_INSTALL_DIR%\java"
move jre\lib "%SPE_INSTALL_DIR%\java\"
if ERRORLEVEL 1 goto ERROR
echo Moving properties to "%SPE_INSTALL_DIR%\java"
set MESSAGE=Failed to move properties to "%SPE_INSTALL_DIR%\java"
move properties "%SPE_INSTALL_DIR%\java\"
if ERRORLEVEL 1 goto ERROR
echo Moving copyright to "%SPE_INSTALL_DIR%\java"
set MESSAGE=Failed to move copyright to "%SPE_INSTALL_DIR%\java"
move copyright "%SPE_INSTALL_DIR%\java\"
if ERRORLEVEL 1 goto ERROR
echo Moving notices.txt to "%SPE_INSTALL_DIR%\java"
set MESSAGE=Failed to move notices.txt to "%SPE_INSTALL_DIR%\java"
move notices.txt "%SPE_INSTALL_DIR%\java\"
if ERRORLEVEL 1 goto ERROR
goto DONE

:UNZIP_FILE <WORK_DIR> <PATCH_ZIP>
set RETURNCODE=1024
set vbs="%temp%\_un31p.vbs"
if exist %vbs% del /f /q %vbs%
>%vbs%  echo set fso = CreateObject("Scripting.FileSystemObject")
>>%vbs% echo If NOT fso.FolderExists(%1) Then
>>%vbs% echo fso.CreateFolder(%1)
>>%vbs% echo End If
>>%vbs% echo set objShell = CreateObject("Shell.Application")
>>%vbs% echo set FilesInZip=objShell.NameSpace(%2).items
>>%vbs% echo objShell.NameSpace(%1).CopyHere(FilesInZip)
>>%vbs% echo set fso = Nothing
>>%vbs% echo set objShell = Nothing
set MESSAGE=Failed to unzip %2
cscript //nologo %vbs%
if ERRORLEVEL 1 goto ERROR
set MESAGE=Failed to delete %vbs%
if exist %vbs% del /f /q %vbs%
if ERRORLEVEL 1 goto ERROR
set RETURNCODE=0
exit /B %RETURNCODE%

:DONE
set MESSAGE=
cd %SPE_INSTALL_DIR%
if exist %WORK_DIR% rd /s /q %WORK_DIR%
echo.
echo %PRODUCT% Java patch resources were deployed successfully
echo.
goto :EOF

:ERROR
echo.
echo.%MESSAGE%
echo.
cd %SPE_INSTALL_DIR%
if exist %WORK_DIR% rd /s /q %WORK_DIR%
if exist %LIST_OF_FILES% del /q /f %LIST_OF_FILES%
goto :EOF

:SYNTAX
echo Deploys %PRODUCT% Java patch resources
echo.
echo speinstall-java-patch.bat -j \path\to\patch.zip
echo.
echo Command line arguments:
echo -j  (Required) Path to the %PRODUCT% Java patch zip file
echo.
goto :EOF

:EOF
